PTBTree

Enum PTBTree 

pub enum PTBTree {
    InnerNode {
        label: String,
        children: Vec<PTBTree>,
    },
    TerminalNode {
        label: String,
    },
}
Arbitrarily wide recursive trees of String.

Variants



InnerNode

Fields

label: String
children: Vec<PTBTree>


TerminalNode

Fields

label: String

Implementations

Source

impl PTBTree

pub fn render(&self) -> String

Return bracketed (and outside-bracketed!) PTB notation:

use ptb_reader::PTBTree;
let tree = PTBTree::InnerNode{ label: "NT".to_string(), children: vec![PTBTree::TerminalNode{ label: "t".to_string() }] };
assert_eq!(tree.render(), "((NT t))")
pub fn front(&self) -> String

Return String from joined terminals at the leaves (i.e, front, yield).

use ptb_reader::PTBTree;
let tree = PTBTree::InnerNode{ label: "NT".to_string(), children: vec![PTBTree::TerminalNode{ label: "t".to_string() }] };
assert_eq!(tree.front(), "t")
pub fn pos_front(&self) -> String

Return String from joined pre-terminals (i.e., POS tags).

use ptb_reader::PTBTree;
let tree = PTBTree::InnerNode{ label: "NT".to_string(), children: vec![PTBTree::TerminalNode{ label: "t".to_string() }] };
assert_eq!(tree.pos_front(), "NT")
pub fn front_length(&self) -> usize

Return number of terminal words, i.e. length of front.

pub fn strip_all_predicate_annotations(&mut self)

Remove predicate-argument annotations and trace elements. See <http://dx.doi.org/10.3115/1075812.1075835 The Penn Treebank: annotating predicate argument structure>. Thanks to Toni Dietze for formalizing the necessary stripping :)